pub enum Relation {
Calls,
Uses,
Imports,
Contains,
Implements,
Extends,
Reads,
Writes,
Creates,
Alters,
Drops,
}Variants
Calls
Uses
Imports
Contains
Implements
Extends
Reads
The source reads rows from the destination relation.
Writes
The source can insert, update, or delete rows in the destination table.
Creates
The source declares creation of the destination database object.
Alters
The source changes the destination database object.
Drops
The source declares removal of the destination database object.
Implementations